Name:           ocaml-creal
Version:        0.7
Release:        %mkrel 20
License:        LGPLv2
Group:          Development/OCaml
Summary:        Exact real arithmetic for OCaml
URL:            http://www.lri.fr/~filliatr/creal.en.html
Source0:        http://www.lri.fr/~filliatr/ftp/ocaml/ds/creal-%{version}.tar.gz
Source1:        ocaml-creal-META
Patch0:         creal-0.7-int32_uint32.patch
Patch1:		Fix-compilation-with-gcc-10.patch
BuildRequires:  ocaml
BuildRequires:  gmp-devel

%description
Creal is an exact real arithmetic library for Objective Caml.
This module implements exact real arithmetic, following Valerie
Menissier-Morain Ph.D. thesis (http://www-calfor.lip6.fr/~vmm/).
A real x is represented as a function giving, for any n, an
approximation zn/4^n of x such that |zn/4^n - x| < 1, where zn is an
arbitrary precision integer (of type Gmp.Z.t).
Coercions from type int, Gmp.Z.t, Gmp.Q.t, basic operations (addition,
subtraction, multiplication, division, power, square root) and
transcendental functions (sin, cos, tan, log, exp, arcsin, arccos,
etc.) and a few constants (pi, e) are provided.
A small reverse-polish calculator is provided to test the library.
Written by Jean-Christophe Filliatre.

%package devel
Summary:        Exact real arithmetic for Objective Caml
Group:          Development/OCaml
Requires:       gmp-devel
Requires:       %{name} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%prep
%setup -q -n creal-%{version}
%autopatch -p1

chmod 644 README CHANGES *.mli mlgmp/*.mli
perl -pi -e 's/\015$//' README
cp %{SOURCE1} META
sed -i -e 's:@VERSION@:%{version}:g' META

%build
%configure
make OCAMLOPT="ocamlopt -g"

%install
make install BINDIR=%{buildroot}%{_bindir} LIBDIR=%{buildroot}%{_libdir}/ocaml/creal

cp META dllcreal.so %{buildroot}%{_libdir}/ocaml/creal/

%files
%doc README CHANGES
%dir %{_libdir}/ocaml/creal
%{_libdir}/ocaml/creal/META
%{_libdir}/ocaml/creal/*.cmi
%{_libdir}/ocaml/creal/*.cma
%{_libdir}/ocaml/creal/*.so*
%{_bindir}/ecalc

%files devel
%{_libdir}/ocaml/creal/*.a
%{_libdir}/ocaml/creal/*.cmxa
%{_libdir}/ocaml/creal/*.mli


%changelog
* Fri Aug 21 2020 pterjan <pterjan> 0.7-20.mga8
+ Revision: 1617692
- Add Debian patch to fix build with GCC 10
+ umeabot <umeabot>
- Rebuild for new ocaml deps generator

* Fri Feb 28 2020 umeabot <umeabot> 0.7-19.mga8
+ Revision: 1551137
- Rebuild for ocaml 4.10.0 final

* Thu Feb 20 2020 umeabot <umeabot> 0.7-18.mga8
+ Revision: 1545289
- Mageia 8 Mass Rebuild

* Tue Jan 28 2020 tv <tv> 0.7-17.mga8
+ Revision: 1484332
- rebuild for ocaml-4.10
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Oct 23 2018 tv <tv> 0.7-16.mga7
+ Revision: 1324042
- rebuild with ocaml-4.07.1

* Mon Oct 22 2018 pterjan <pterjan> 0.7-15.mga7
+ Revision: 1323730
- Rebuild for ocaml 4.07

* Sun Sep 23 2018 umeabot <umeabot> 0.7-14.mga7
+ Revision: 1299855
- Mageia 7 Mass Rebuild

* Sun Nov 26 2017 tv <tv> 0.7-13.mga7
+ Revision: 1179495
- rebuild for new ocaml

* Thu Oct 12 2017 daviddavid <daviddavid> 0.7-12.mga7
+ Revision: 1171142
- patch0: use standard ISO C99 types {,u}int{32,64}_t
- fix invalid utf-8 encoding in Description

* Thu Oct 05 2017 daviddavid <daviddavid> 0.7-11.mga7
+ Revision: 1169212
- enable debugging information thus fixing empty debugsourcefiles.list

* Mon Sep 26 2016 pterjan <pterjan> 0.7-10.mga6
+ Revision: 1056313
- Rebuild for fix in ocaml

* Fri Feb 12 2016 umeabot <umeabot> 0.7-9.mga6
+ Revision: 956317
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.7-8.mga5
+ Revision: 747921
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.7-7.mga5
+ Revision: 683011
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.7-6.mga4
+ Revision: 535760
- Mageia 4 Mass Rebuild

* Fri Sep 20 2013 malo <malo> 0.7-5.mga4
+ Revision: 482446
- rebuild for ocaml-4.01.0

* Sat Jan 12 2013 umeabot <umeabot> 0.7-4.mga3
+ Revision: 361235
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 01 2012 blue_prawn <blue_prawn> 0.7-3.mga3
+ Revision: 301645
- new rpm group for ocaml
- new rpm group for ocaml

* Thu Apr 12 2012 blue_prawn <blue_prawn> 0.7-1.mga2
+ Revision: 230541
- imported package ocaml-creal

